@@ -11,6 +11,9 @@
 #ifndef KBLOCKSSOUND_H
 #define KBLOCKSSOUND_H
 
+#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
+#include <libkdegamesprivate/kgametheme.h>
+
 class KgSound;
 
 enum class Sound {
@@ -22,17 +25,18 @@ enum class Sound {
 class KBlocksSound
 {
 public:
-    KBlocksSound();
+    KBlocksSound(const QString &themeFile);
     ~KBlocksSound();
 
 public:
+    bool loadTheme(const QString &themeFile);
     void setSoundsEnabled(bool p_enabled);
     void playSound(Sound soundType);
 
 private:
-    KgSound *m_blockFallSound;
-    KgSound *m_blockMoveSound;
-    KgSound *m_blockRemoveSound;
+    KgSound *m_blockFallSound = nullptr;
+    KgSound *m_blockMoveSound = nullptr;
+    KgSound *m_blockRemoveSound = nullptr;
     bool sndActive;
 
 };
